package repos

import (
	"context"
	"gralias/models"
)

type PlayersRepo interface {
	GetPlayerByName(username string) (*models.Player, error)
	AddPlayer(player *models.Player) error
	DeletePlayer(roomID, username string) error
}

func (p *RepoProvider) GetPlayerByName(username string) (*models.Player, error) {
	var player models.Player
	err := p.DB.GetContext(context.Background(), &player, "SELECT id, room_id, username, team, role, is_bot FROM players WHERE username = ?", username)
	if err != nil {
		return nil, err
	}
	return &player, nil
}

func (p *RepoProvider) AddPlayer(player *models.Player) error {
	_, err := p.DB.ExecContext(context.Background(), "INSERT INTO players (room_id, username, team, role, is_bot) VALUES (?, ?, ?, ?, ?)", player.RoomID, player.Username, player.Team, player.Role, player.IsBot)
	return err
}

func (p *RepoProvider) DeletePlayer(roomID, username string) error {
	_, err := p.DB.ExecContext(context.Background(), "DELETE FROM players WHERE room_id = ? AND username = ?", roomID, username)
	return err
}
