package repos

import (
	"context"
	"gralias/models"
)

type RoomsRepo interface {
	ListRooms(ctx context.Context) ([]*models.Room, error)
	GetRoomByID(ctx context.Context, id string) (*models.Room, error)
	CreateRoom(ctx context.Context, room *models.Room) error
	DeleteRoomByID(ctx context.Context, id string) error
	UpdateRoom(ctx context.Context, room *models.Room) error
}

func (p *RepoProvider) ListRooms(ctx context.Context) ([]*models.Room, error) {
	rooms := []*models.Room{}
	err := p.DB.SelectContext(ctx, &rooms, `SELECT * FROM rooms`)
	if err != nil {
		return nil, err
	}
	return rooms, nil
}

func (p *RepoProvider) GetRoomByID(ctx context.Context, id string) (*models.Room, error) {
	room := &models.Room{}
	err := p.DB.GetContext(ctx, room, `SELECT * FROM rooms WHERE id = ?`, id)
	if err != nil {
		return nil, err
	}
	return room, nil
}

func (p *RepoProvider) CreateRoom(ctx context.Context, r *models.Room) error {
	_, err := p.DB.ExecContext(ctx, `INSERT INTO rooms (id, created_at, creator_name, team_turn, this_turn_limit, opened_this_turn, blue_counter, red_counter, red_turn, mime_done, is_running, round_time, is_over, team_won, room_pass) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)`, r.ID, r.CreatedAt, r.CreatorName, r.TeamTurn, r.ThisTurnLimit, r.OpenedThisTurn, r.BlueCounter, r.RedCounter, r.RedTurn, r.MimeDone, r.IsRunning, r.RoundTime, r.IsOver, r.TeamWon, r.RoomPass)
	return err
}

func (p *RepoProvider) DeleteRoomByID(ctx context.Context, id string) error {
	_, err := p.DB.ExecContext(ctx, `DELETE FROM rooms WHERE id = ?`, id)
	return err
}

func (p *RepoProvider) UpdateRoom(ctx context.Context, r *models.Room) error {
	_, err := p.DB.ExecContext(ctx, `UPDATE rooms SET team_turn = ?, this_turn_limit = ?, opened_this_turn = ?, blue_counter = ?, red_counter = ?, red_turn = ?, mime_done = ?, is_running = ?, round_time = ?, is_over = ?, team_won = ?, room_pass = ? WHERE id = ?`, r.TeamTurn, r.ThisTurnLimit, r.OpenedThisTurn, r.BlueCounter, r.RedCounter, r.RedTurn, r.MimeDone, r.IsRunning, r.RoundTime, r.IsOver, r.TeamWon, r.RoomPass, r.ID)
	return err
}
